@@ -87,7 +87,6 @@ class RemoteVideoTrack:
     def get_statistics(self):
         stats_ptr = agora_remote_video_track_get_statistics(self.track_handle)
         if not stats_ptr:
-            logger.error("Failed to get remote video track statistics")
             return None
         stats = stats_ptr.contents
         self.destroy_statistics(stats_ptr)
@@ -102,7 +101,6 @@ class RemoteVideoTrack:
     def get_track_info(self):
         info_ptr = agora_remote_video_track_get_track_info(self.track_handle)
         if not info_ptr:
-            logger.error("Failed to get remote video track info")
             return None
         info = info_ptr.contents
         self.destroy_track_info(info_ptr)
@@ -113,28 +111,21 @@ class RemoteVideoTrack:
 
     def register_video_encoded_image_receiver(self, receiver):
         ret = agora_remote_video_track_register_video_encoded_image_receiver(self.track_handle, receiver)
-        if ret != 0:
-            logger.error(f"Failed to register video encoded image receiver, error code: {ret}")
         return ret
 
     def unregister_video_encoded_image_receiver(self, receiver):
         ret = agora_remote_video_track_unregister_video_encoded_image_receiver(self.track_handle, receiver)
-        if ret != 0:
-            logger.error(f"Failed to unregister video encoded image receiver, error code: {ret}")
         return ret
 
     # def register_media_packet_receiver(self, receiver):
     #     ret = agora_remote_video_track_register_media_packet_receiver(self.track_handle, receiver)
-    #     if ret != 0:
-    #         logger.error(f"Failed to register media packet receiver, error code: {ret}")
     #     return ret
 
     # def unregister_media_packet_receiver(self, receiver):
     #     ret = agora_remote_video_track_unregister_media_packet_receiver(self.track_handle, receiver)
-    #     if ret != 0:
-    #         logger.error(f"Failed to unregister media packet receiver, error code: {ret}")
     #     return ret
 
-    def get_type(self):
-        return agora_remote_video_track_get_type(self.track_handle)
+    # def get_type(self):
+    #     ret =  agora_remote_video_track_get_type(self.track_handle)
+    #     return ret
 
